{ config, pkgs, discord, inputs, nixpkgs-nixos-unstable-and-unfree, ... }:
let
  unstable = inputs.nixpkgs-nixos-unstable.legacyPackages.${pkgs.system};
in
{
  programs.firejail.enable = true;
  programs.firejail.wrappedBinaries = {
    firefox = {
      executable = "${pkgs.lib.getBin pkgs.firefox}/bin/firefox";
      profile = "${pkgs.firejail}/etc/firejail/firefox.profile";
    };
    chromium = {
      executable = "${pkgs.lib.getBin pkgs.chromium}/bin/chromium";
      profile = "${pkgs.firejail}/etc/firejail/chromium.profile";
    };
  };

  security.chromiumSuidSandbox.enable = true;

  home-manager.users.cyryl = { ... }: {
    gtk = {
      enable = true;
      iconTheme = {
        name = "Adwaita";
        package = pkgs.gnome3.adwaita-icon-theme;
      };
    };
    qt = {
      enable = true;
      platformTheme = "gnome";
      style.name = "adwaita-dark";
      style.package = pkgs.adwaita-qt;
    };

    imports = [
      ./firejail.nix
    ];

    home.packages = with pkgs; with pkgs.gnome3; with pkgs.python38Packages; [
      anarchism
      binwalk-full
      brave
      cheese
      digikam
      electrum
      element-desktop
      eog
      evince
      fontconfig
      freecad
      ghidra-bin
      gimp
      glxinfo
      gnome-screenshot
      gsettings-desktop-schemas
      inkscape
      libreoffice
      mindforger
      modem-manager-gui
      nautilus
      nyxt
      obs-studio
      openscad
      passff-host
      pdfarranger
      qcad
      qemu
      remmina
      shotwell
      signal-desktop
      simple-scan
      ssb-patchwork
      tlaplusToolbox
      tlaps
      vlc
      wineFull
      wireshark
      wsjtx
      xclip
      xidlehook
      yubico-piv-tool
      yubikey-manager-qt
      yubikey-personalization
      yubikey-personalization-gui
    ] ++
    [
      nixpkgs-nixos-unstable-and-unfree.discord
      nixpkgs-nixos-unstable-and-unfree.hopper
      nixpkgs-nixos-unstable-and-unfree.slack
      nixpkgs-nixos-unstable-and-unfree.spotify
      nixpkgs-nixos-unstable-and-unfree.zoom-us
    ];
  };
}
